// Copyright 2023 Woodpecker Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package plugin

import (
	"time"

	"github.com/urfave/cli/v3"
)

// Step defines runtime metadata for a step.
type Step struct {
	Number   int       `json:"number,omitempty"`
	Started  time.Time `json:"started,omitempty"`
	Finished time.Time `json:"finished,omitempty"`
}

func stepFlags() []cli.Flag {
	return []cli.Flag{
		&cli.IntFlag{
			Name:  "step.number",
			Usage: "step number",
			Sources: cli.EnvVars(
				"CI_STEP_NUMBER",
				"DRONE_STEP_NUMBER",
			),
		},
		&cli.IntFlag{
			Name:  "step.started",
			Usage: "step start time",
			Sources: cli.EnvVars(
				"CI_STEP_STARTED",
			),
		},
		&cli.IntFlag{
			Name:  "step.finished",
			Usage: "step finish time",
			Sources: cli.EnvVars(
				"CI_STEP_FINISHED",
			),
		},
	}
}

func stepFromContext(c *cli.Command) Step {
	return Step{
		Number:   int(c.Int("step.number")),
		Started:  time.Unix(c.Int("step.started"), 0),
		Finished: time.Unix(c.Int("step.finished"), 0),
	}
}
